level

# XMLRésuméLibrary: User Guide

legalnotice | Element Reference | link

## Name

level — A degree type

## Synopsis

### Content Model

    (#PCDATA)

### Attributes

Name | Type | Default
--- | --- | ---
targets | CDATA | None

## Description

The semantic of the `title` element vary depending on which element contains it:

`clearance`

  When contained in this element, the `level` element specifies the level of security clearance that a person has been granted, such as “Top Secret” or “Restricted”.

`degree`

  When contained in this element, the `level` element specifies a degree type, such as “BFA” (bachelor of fine arts) or “Ph.D” (doctor of philosophy). It typically contains the abbreviation (“BS”) not the full spelling (“bachelor of science”).

### Parents

`level` may be contained in these elements: `clearance`, `degree`

## Examples

For examples, see `clearance` and `degree`.

legalnotice | Element Reference | link